@@ -140,7 +140,7 @@ class Sync(Base):
                 tables |= set(node.through_tables)
                 tables |= set([node.table])
             self.create_triggers(self.database, schema, tables=tables)
-        self.create_logical_replication_slot(self.__name)
+        self.create_replication_slot(self.__name)
 
     def teardown(self):
         """Drop the database triggers and replication slot."""
